# Responsible AI Vision SDK for Python

### This package has been tested with Python 3.6, 3.7, 3.8 and 3.9

The Responsible AI Vision sdk enables users to analyze their machine learning models for computer vision in one API. Users will be able to analyze errors, explain the most important features, and understand their data using a single API.

Highlights of the package include:

- `explainer.add()` explains the model

### Supported scenarios, models and datasets

The Responsible AI Vision SDK supports multiclass classification models on image data currently.

The open source code for the visualization dashboard can be found here:
https://github.com/microsoft/responsible-ai-widgets
